## 0.2.1 (2023-02-08)

### Fix

- static method on_forgot_password_param_error

## 0.2.0 (2023-02-08)

### Feat

- improve codes

## 0.1.1 (2023-02-07)

### Fix

- create cache dir error when write last login account to cache

## 0.1.0 (2023-02-07)

### Feat

- create a qt window to login in ArtHub
